==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/widgets/percentwidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** percentwidget.h
*/
#ifndef __PercentWidget_H__
#define __PercentWidget_H__

#include <qwidget.h>
#include <qlabel.h>
#include <qtooltip.h>
//#include <qslider.h>
#include <qsize.h>

class QSlider;
class	 PercentWidget : public QWidget
{
Q_OBJECT
protected:
	
        QSlider *slider;
	QLabel *label,*valuel;
	double value;

public:
	PercentWidget(QWidget *parent,char*n="",double v=0);
	~PercentWidget();

	double	getValue();
	void	setValue(double);

public slots:
	void	paintEvent(QPaintEvent *);
        void 	changed(int);

};


#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/widgets/percentwidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** percentwidget.h
*/
#ifndef __PercentWidget_H__
#define __PercentWidget_H__

#include <qwidget.h>
#include <qlabel.h>
#include <qtooltip.h>
//#include <qslider.h>
#include <qsize.h>

class QSlider;
class	 PercentWidget : public QWidget
{
Q_OBJECT
protected:
	
        QSlider *slider;
	QLabel *label,*valuel;
	double value;
	QSize	qs;
	int	tab;

public:
	PercentWidget(QWidget *parent,const char*n="",double v=0);
	~PercentWidget();

	double	getValue();
	void	setValue(double);
	QSize	sizeHint();
	int	getLabelWidth();
	void	setTab(int);
	int 	layout(PercentWidget *w1=NULL,PercentWidget *w2=NULL,PercentWidget *w3=NULL,PercentWidget *w4=NULL);

public slots:
	void	paintEvent(QPaintEvent *);
        void 	changed(int);

signals:
	void 	valueChanged();
};


#endif
